import { IacProjectType } from '../../../../lib/iac/constants';
import { SEVERITY } from '../../../../lib/snyk-test/common';
import { IacFileInDirectory, Options, TestOptions } from '../../../../lib/types';
export interface IacFileData extends IacFileInDirectory {
    fileContent: string;
}
export declare const VALID_FILE_TYPES: string[];
export interface IacFileParsed extends IacFileData {
    jsonContent: Record<string, unknown> | TerraformScanInput;
    engineType: EngineType;
    docId?: number;
}
export interface IacFileParseFailure extends IacFileData {
    jsonContent: null;
    engineType: null;
    failureReason: string;
    err: Error;
}
export declare type ScanningResults = {
    scannedFiles: Array<IacFileScanResult>;
    unscannedFiles: Array<IacFileParseFailure>;
};
export declare type ParsingResults = {
    parsedFiles: Array<IacFileParsed>;
    failedFiles: Array<IacFileParseFailure>;
};
export interface IacFileScanResult extends IacFileParsed {
    violatedPolicies: PolicyMetadata[];
}
export declare type FormattedResult = {
    result: {
        cloudConfigResults: Array<PolicyMetadata>;
    };
    isPrivate: boolean;
    packageManager: IacProjectType;
    targetFile: string;
};
export interface OpaWasmInstance {
    evaluate: (data: Record<string, any>) => {
        results: PolicyMetadata[];
    };
    setData: (data: Record<string, any>) => void;
}
export declare type SafeAnalyticsOutput = Omit<IacFileParsed | IacFileParseFailure, 'fileContent' | 'jsonContent' | 'engineType'>;
export declare enum EngineType {
    Kubernetes = 0,
    Terraform = 1
}
export interface PolicyMetadata {
    id: string;
    publicId: string;
    type: string;
    subType: string;
    title: string;
    description: string;
    severity: SEVERITY;
    msg: string;
    policyEngineType: 'opa';
    issue: string;
    impact: string;
    resolve: string;
    references: string[];
}
export declare type IaCTestFlags = Pick<Options & TestOptions, 'insecure' | 'debug' | 'experimental' | 'detectionDepth' | 'severityThreshold' | 'json' | 'sarif'> & {
    'json-file-output'?: string;
    'sarif-file-output'?: string;
    v?: boolean;
    version?: boolean;
    h?: boolean;
    help?: 'help';
    q?: boolean;
    quiet?: boolean;
};
export declare type IaCTestOptions = IaCTestFlags & {
    /** @deprecated Only used by the legacy `iac test` flow remove once local exec path is GA */
    iacDirFiles?: Array<IacFileInDirectory>;
};
export interface TerraformPlanResource {
    address: string;
    mode: string;
    type: string;
    name: string;
    values: Record<string, unknown>;
    index: number;
}
export interface TerraformPlanResourceChange extends Omit<TerraformPlanResource, 'values'> {
    change: {
        actions: ResourceActions;
        before: Record<string, unknown> | null;
        after: Record<string, unknown> | null;
    };
}
export interface TerraformPlanJson {
    planned_values: {
        root_module: {
            resources: Array<TerraformPlanResource>;
            child_modules: Array<{
                resources: Array<TerraformPlanResource>;
            }>;
        };
    };
    resource_changes: Array<TerraformPlanResourceChange>;
}
export interface TerraformScanInput {
    resource: Record<string, Record<string, unknown>>;
    data: Record<string, Record<string, unknown>>;
}
export declare type ResourceActions = ['no-op'] | ['create'] | ['read'] | ['update'] | ['delete', 'create'] | ['create', 'delete'] | ['delete'];
export declare const VALID_RESOURCE_ACTIONS: ResourceActions[];
export declare enum IaCErrorCodes {
    FailedToInitLocalCacheError = 1000,
    FailedToCleanLocalCacheError = 1001,
    NoFilesToScanError = 1010,
    FailedToLoadFileError = 1011,
    UnsupportedFileTypeError = 1020,
    FailedToParseKubernetesYamlError = 1030,
    MissingRequiredFieldsInKubernetesYamlError = 1031,
    FailedToParseTerraformFileError = 1040,
    FailedToParseTerraformPlanJsonError = 1050,
    MissingRequiredFieldsInTerraformPlanError = 1051,
    FailedToExtractResourcesInTerraformPlanError = 1052,
    FailedToBuildPolicyEngine = 1060,
    FailedToExecutePolicyEngine = 1061,
    FailedToFormatResults = 1070
}
